@@ -5,19 +5,20 @@ from typing import Literal, cast
 from fastapi import FastAPI
 from starlette.middleware.sessions import SessionMiddleware
 
-from svc_infra.api.fastapi.auth.mfa import mfa_router
+from svc_infra.api.fastapi.auth.gaurd import auth_session_router, login_client_guard
+from svc_infra.api.fastapi.auth.mfa.pre_auth import get_mfa_pre_jwt_writer
+from svc_infra.api.fastapi.auth.mfa.router import mfa_router
 from svc_infra.api.fastapi.db.sql.users import get_fastapi_users
+from svc_infra.api.fastapi.openapi.security import install_openapi_auth
 from svc_infra.app.env import CURRENT_ENVIRONMENT, DEV_ENV, LOCAL_ENV
 from svc_infra.db.sql.apikey import bind_apikey_model
 
 from .. import Require
+from ..openapi.conventions import install_openapi_conventions
 from .account import account_router
 from .apikey_router import apikey_router
-from .gaurd import login_client_guard, mfa_login_router
 from .oauth_router import oauth_router_with_backend
-from .openapi_security import install_openapi_auth
 from .policy import AuthPolicy, DefaultAuthPolicy
-from .pre_auth import get_mfa_pre_jwt_writer
 from .providers import providers_from_settings
 from .settings import get_auth_settings
 from .state import set_auth_state
@@ -90,9 +91,9 @@ def add_auth(
             bind_apikey_model(user_model, table_name=apikey_table_name)
             app.include_router(apikey_router(), include_in_schema=include_in_docs)
 
-        # MFA-aware login
+        # Auth session endpoints (login/logout)
         app.include_router(
-            mfa_login_router(
+            auth_session_router(
                 fapi=fapi,
                 auth_backend=auth_backend,
                 user_model=user_model,
@@ -164,5 +165,5 @@ def add_auth(
                 include_in_schema=include_in_docs,
             )
 
-    if include_in_docs and (enable_password or enable_oauth or enable_api_keys):
-        install_openapi_auth(app)
+    install_openapi_auth(app, include_api_key=enable_api_keys)
+    install_openapi_conventions(app)
