@@ -1,16 +1,17 @@
 from __future__ import annotations
 
-from typing import Any, Callable, Optional, Sequence
+from typing import Any, Optional, Sequence
 
-from svc_infra.api.fastapi.auth.security import RequireIdentity  # for router-level dependencies
-from svc_infra.api.fastapi.auth.security import RequireScopes  # guard factory
-from svc_infra.api.fastapi.auth.security import RequireService  # guard factory
-from svc_infra.api.fastapi.auth.security import RequireUser  # guard factory
-from svc_infra.api.fastapi.auth.security import (  # for router-level dependencies
+from ..auth.security import (
     AllowIdentity,
+    RequireIdentity,
     RequireRoles,
+    RequireScopes,
+    RequireService,
+    RequireUser,
 )
-
+from ..openapi.apply import apply_default_responses, apply_default_security
+from ..openapi.responses import DEFAULT_PROTECTED, DEFAULT_PUBLIC, DEFAULT_SERVICE, DEFAULT_USER
 from .router import DualAPIRouter
 
 
@@ -23,27 +24,13 @@ def _merge(base: Optional[Sequence[Any]], extra: Optional[Sequence[Any]]) -> lis
     return out
 
 
-def _apply_default_security(router: DualAPIRouter, default_security: list[dict] | None) -> None:
-    if default_security is None:
-        return
-    original_add = router.add_api_route
-
-    def _wrapped_add_api_route(path: str, endpoint: Callable, **kwargs: Any):
-        ox = kwargs.get("openapi_extra") or {}
-        if "security" not in ox:
-            ox["security"] = default_security
-            kwargs["openapi_extra"] = ox
-        return original_add(path, endpoint, **kwargs)
-
-    router.add_api_route = _wrapped_add_api_route  # type: ignore[attr-defined]
-
-
 # PUBLIC (but attach OptionalIdentity for convenience)
 def optional_identity_router(
     *, dependencies: Optional[Sequence[Any]] = None, **kwargs: Any
 ) -> DualAPIRouter:
     r = DualAPIRouter(dependencies=_merge([AllowIdentity], dependencies), **kwargs)
-    _apply_default_security(r, default_security=[])  # public looking in docs
+    apply_default_security(r, default_security=[])  # public looking in docs
+    apply_default_responses(r, DEFAULT_PUBLIC)
     return r
 
 
@@ -52,44 +39,48 @@ def protected_router(
     *, dependencies: Optional[Sequence[Any]] = None, **kwargs: Any
 ) -> DualAPIRouter:
     r = DualAPIRouter(dependencies=_merge([RequireIdentity], dependencies), **kwargs)
-    _apply_default_security(
+    apply_default_security(
         r,
         default_security=[
             {"OAuth2PasswordBearer": []},
             {"SessionCookie": []},
-            {"ApiKeyHeader": []},
+            {"APIKeyHeader": []},
         ],
     )
+    apply_default_responses(r, DEFAULT_PROTECTED)
     return r
 
 
 # USER-ONLY (no API-key-only access)
 def user_router(*, dependencies: Optional[Sequence[Any]] = None, **kwargs: Any) -> DualAPIRouter:
     r = DualAPIRouter(dependencies=_merge([RequireUser()], dependencies), **kwargs)
-    _apply_default_security(
+    apply_default_security(
         r, default_security=[{"OAuth2PasswordBearer": []}, {"SessionCookie": []}]
     )
+    apply_default_responses(r, DEFAULT_USER)
     return r
 
 
 # SERVICE-ONLY (API key required)
 def service_router(*, dependencies: Optional[Sequence[Any]] = None, **kwargs: Any) -> DualAPIRouter:
     r = DualAPIRouter(dependencies=_merge([RequireService()], dependencies), **kwargs)
-    _apply_default_security(r, default_security=[{"ApiKeyHeader": []}])
+    apply_default_security(r, default_security=[{"APIKeyHeader": []}])
+    apply_default_responses(r, DEFAULT_SERVICE)
     return r
 
 
 # SCOPE-GATED (works with user scopes and api-key scopes)
 def scopes_router(*scopes: str, **kwargs: Any) -> DualAPIRouter:
     r = DualAPIRouter(dependencies=[RequireIdentity, RequireScopes(*scopes)], **kwargs)
-    _apply_default_security(
+    apply_default_security(
         r,
         default_security=[
             {"OAuth2PasswordBearer": []},
             {"SessionCookie": []},
-            {"ApiKeyHeader": []},
+            {"APIKeyHeader": []},
         ],
     )
+    apply_default_responses(r, DEFAULT_PROTECTED)
     return r
 
 
@@ -98,7 +89,8 @@ def roles_router(*roles: str, role_resolver=None, **kwargs):
     r = DualAPIRouter(
         dependencies=[RequireUser(), RequireRoles(*roles, resolver=role_resolver)], **kwargs
     )
-    _apply_default_security(
+    apply_default_security(
         r, default_security=[{"OAuth2PasswordBearer": []}, {"SessionCookie": []}]
     )
+    apply_default_responses(r, DEFAULT_USER)
     return r
