@@ -13,8 +13,15 @@ from fastapi.routing import APIRoute
 
 from svc_infra.api.fastapi.docs.landing import CardSpec, DocTargets, render_index_html
 from svc_infra.api.fastapi.middleware.errors.catchall import CatchAllExceptionMiddleware
-from svc_infra.api.fastapi.middleware.errors.error_handlers import register_error_handlers
-from svc_infra.api.fastapi.models import APIVersionSpec, ServiceInfo
+from svc_infra.api.fastapi.middleware.errors.handlers import register_error_handlers
+from svc_infra.api.fastapi.openapi.models import APIVersionSpec, ServiceInfo
+from svc_infra.api.fastapi.openapi.mutators import (
+    auth_mutator,
+    conventions_mutator,
+    info_mutator,
+    servers_mutator,
+)
+from svc_infra.api.fastapi.openapi.pipeline import apply_mutators
 from svc_infra.api.fastapi.routers import register_all_routers
 from svc_infra.app.env import CURRENT_ENVIRONMENT
 
@@ -79,11 +86,62 @@ def _coerce_list(value: str | Iterable[str] | None) -> list[str]:
     return [v for v in value if v]
 
 
+def _apply_info_overrides(app: FastAPI, base: ServiceInfo, spec: APIVersionSpec | None = None):
+    """Apply base ServiceInfo + optional per-child overrides into OpenAPI.info."""
+    prev = getattr(app, "openapi", None)
+
+    def patched():
+        base_schema = (
+            prev()
+            if callable(prev)
+            else get_openapi(title=app.title, version=app.version, routes=app.routes)
+        )
+        schema = dict(base_schema)
+        info = schema.setdefault("info", {})
+        # Base service identity
+        info.setdefault("title", base.name)
+        info.setdefault("version", base.release)
+        if base.description is not None:
+            info["description"] = base.description
+        if base.terms_of_service is not None:
+            info["termsOfService"] = base.terms_of_service
+        if base.contact:
+            info["contact"] = {k: v for k, v in base.contact.model_dump().items() if v is not None}
+        if base.license:
+            info["license"] = {k: v for k, v in base.license.model_dump().items() if v is not None}
+        # Per-child overrides
+        if spec is not None:
+            if spec.description is not None:
+                info["description"] = spec.description
+            if spec.terms_of_service is not None:
+                info["termsOfService"] = spec.terms_of_service
+            if spec.contact is not None:
+                info["contact"] = {
+                    k: v for k, v in spec.contact.model_dump().items() if v is not None
+                }
+            if spec.license is not None:
+                info["license"] = {
+                    k: v for k, v in spec.license.model_dump().items() if v is not None
+                }
+
+        app.openapi_schema = schema
+        return schema
+
+    app.openapi = patched
+
+
 def _set_servers(app: FastAPI, public_base_url: str | None, mount_path: str):
+    """Install servers AFTER all other installers so it wins."""
     base = mount_path if not public_base_url else f"{public_base_url.rstrip('/')}{mount_path}"
+    previous = getattr(app, "openapi", None)
 
     def custom_openapi():
-        schema = get_openapi(title=app.title, version=app.version, routes=app.routes)
+        base_schema = (
+            previous()
+            if callable(previous)
+            else get_openapi(title=app.title, version=app.version, routes=app.routes)
+        )
+        schema = dict(base_schema)
         schema["servers"] = [{"url": base}]
         app.openapi_schema = schema
         return schema
@@ -91,25 +149,44 @@ def _set_servers(app: FastAPI, public_base_url: str | None, mount_path: str):
     app.openapi = custom_openapi
 
 
+def _dump_or_none(model):
+    return model.model_dump(exclude_none=True) if model is not None else None
+
+
 def _build_child_app(service: ServiceInfo, spec: APIVersionSpec) -> FastAPI:
     child = FastAPI(
         title=service.name,
         version=service.release,
+        contact=_dump_or_none(service.contact),  # FastAPI expects plain dicts
+        license_info=_dump_or_none(service.license),
+        terms_of_service=service.terms_of_service,
+        description=service.description,
         generate_unique_id_function=_gen_operation_id_factory(),
-        # let parent control global docs; per-spec override handled via parent index links
     )
 
-    # only parent gets CORS; child shares the same ASGI app after mount
     child.add_middleware(CatchAllExceptionMiddleware)
     register_error_handlers(child)
 
-    # version routers
+    # ---- OpenAPI pipeline (DRY!) ----
+    include_api_key = bool(spec.include_api_key) if spec.include_api_key is not None else False
+    mount_path = f"/{spec.tag.strip('/')}"
+    server_url = (
+        mount_path
+        if not spec.public_base_url
+        else f"{spec.public_base_url.rstrip('/')}{mount_path}"
+    )
+
+    apply_mutators(
+        child,
+        conventions_mutator(),
+        auth_mutator(include_api_key),
+        info_mutator(service, spec),
+        servers_mutator(server_url),
+    )
+
     if spec.routers_package:
         register_all_routers(
-            child,
-            base_package=spec.routers_package,
-            prefix="",  # will be mounted under /{tag}
-            environment=CURRENT_ENVIRONMENT,
+            child, base_package=spec.routers_package, prefix="", environment=CURRENT_ENVIRONMENT
         )
 
     logger.info(
@@ -122,7 +199,6 @@ def setup_service_api(
     *,
     service: ServiceInfo,
     versions: Sequence[APIVersionSpec],
-    root_title: str | None = None,
     root_routers: list[str] | str | None = None,
     public_cors_origins: list[str] | str | None = None,
 ) -> FastAPI:
@@ -132,11 +208,15 @@ def setup_service_api(
       - One child app per APIVersionSpec mounted at /{tag}
     """
     parent = FastAPI(
-        title=root_title or service.name,
+        title=service.name,
+        version=service.release,
+        contact=_dump_or_none(service.contact),
+        license_info=_dump_or_none(service.license),
+        terms_of_service=service.terms_of_service,
+        description=service.description,
         docs_url="/docs",
         redoc_url="/redoc",
         openapi_url="/openapi.json",
-        version=service.release,
     )
 
     _setup_cors(parent, public_cors_origins)
